==> concierge-1.0.0-alpha1-sources.jar: com/flybits/concierge/viewholders/ImageViewHolder.java <==
package com.flybits.concierge.viewholders;

import android.view.View;
import android.widget.ImageView;

import com.flybits.concierge.ConciergeFragment;
import com.flybits.concierge.FlybitsNavigator;
import com.flybits.concierge.FlybitsViewPopulator;
import com.flybits.concierge.R;
import com.flybits.concierge.models.Images;

public class ImageViewHolder extends FlybitsViewHolder<Images>
{
    private View thisView;
    private ImageView singleView;
    private View doubleView;
    private View multipleView;

    private ImageView[] doubleImages;
    private ImageView[] multipleImages;

    private ConciergeFragment conciergeFragment;

    private Images currentBoundImage;

    private FlybitsViewPopulator flybitsViewPopulator;

    public ImageViewHolder(ConciergeFragment conciergeFragment, View itemView, FlybitsViewPopulator flybitsViewPopulator)
    {
        super(itemView);
        this.conciergeFragment = conciergeFragment;
        this.thisView = itemView;

        singleView = itemView.findViewById(R.id.flybits_con_item_image_imgSingle);

        doubleImages = new ImageView[] {
                itemView.findViewById(R.id.flybits_con_item_image_imgDoubleLeft),
                itemView.findViewById(R.id.flybits_con_item_image_imgDoubleRight)
        };

        multipleImages = new ImageView[] {
                itemView.findViewById(R.id.flybits_con_item_image_imgBig),
                itemView.findViewById(R.id.flybits_con_item_image_imgTR),
                itemView.findViewById(R.id.flybits_con_item_image_imgBR)
        };

        doubleView = itemView.findViewById(R.id.flybits_con_item_image_lytDouble);
        multipleView = itemView.findViewById(R.id.flybits_con_item_image_lytTriple);

        this.flybitsViewPopulator = flybitsViewPopulator;
    }

    @Override
    public void bindData(final Images images, FlybitsNavigator flybitsNavigator)
    {
        currentBoundImage = images;
        flybitsViewPopulator.populateImagesViews(images, conciergeFragment, thisView, singleView
                , doubleView, multipleView, doubleImages, multipleImages, currentBoundImage);
    }
}

==> concierge-1.4.3-alpha1-sources.jar: com/flybits/concierge/viewholders/ImageViewHolder.java <==
package com.flybits.concierge.viewholders;

import android.view.View;
import android.widget.ImageView;

import com.flybits.concierge.FlybitsNavigator;
import com.flybits.concierge.FlybitsViewPopulator;
import com.flybits.concierge.R;
import com.flybits.concierge.models.Images;

public class ImageViewHolder extends FlybitsViewHolder<Images>
{
    private View thisView;
    private ImageView singleView;
    private View doubleView;
    private View multipleView;

    private ImageView[] doubleImages;
    private ImageView[] multipleImages;

    private Images currentBoundImage;

    private FlybitsViewPopulator flybitsViewPopulator;

    public ImageViewHolder(View itemView, FlybitsViewPopulator flybitsViewPopulator)
    {
        super(itemView);
        this.thisView = itemView;

        singleView = itemView.findViewById(R.id.flybits_con_item_image_imgSingle);

        doubleImages = new ImageView[] {
                itemView.findViewById(R.id.flybits_con_item_image_imgDoubleLeft),
                itemView.findViewById(R.id.flybits_con_item_image_imgDoubleRight)
        };

        multipleImages = new ImageView[] {
                itemView.findViewById(R.id.flybits_con_item_image_imgBig),
                itemView.findViewById(R.id.flybits_con_item_image_imgTR),
                itemView.findViewById(R.id.flybits_con_item_image_imgBR)
        };

        doubleView = itemView.findViewById(R.id.flybits_con_item_image_lytDouble);
        multipleView = itemView.findViewById(R.id.flybits_con_item_image_lytTriple);

        this.flybitsViewPopulator = flybitsViewPopulator;
    }

    @Override
    public void bindData(final Images images, FlybitsNavigator flybitsNavigator)
    {
        currentBoundImage = images;
        flybitsViewPopulator.populateImagesViews(images, flybitsNavigator, thisView, singleView
                , doubleView, multipleView, doubleImages, multipleImages, currentBoundImage);
    }
}
